@@ -2,9 +2,9 @@
 
 __author__ = """Yossi Mosbacher"""
 __email__ = "joe.mosbacher@gmail.com"
-__version__ = "0.1.5"
+__version__ = "0.1.6"
 
-from .dispatchers import json_serializable, get_widget
+from .dispatchers import json_serializable, infer_widget
 from .widgets import (
     PydanticModelEditor,
     PydanticModelEditorCard,
